pub struct ItemData {
pub id: i32,
pub name: String,
pub max_count: u32,
pub attributes: ItemAttributesContainer,
pub default_properties: ItemPropertiesContainer,
}Fields
id: i32name: Stringmax_count: u32How many instances of this item a user can own E.g. you might have one instance of a certain type of bait, BUT the instance might be stackable and store a count, making it seem like you own multiple instances of this item. Defaults to one.
attributes: ItemAttributesContainerdefault_properties: ItemPropertiesContainerTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ItemData
impl<'de> Deserialize<'de> for ItemData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ItemAttributesContainerInterface for ItemData
impl ItemAttributesContainerInterface for ItemData
fn get_attributes(&self) -> &HashMap<ItemAttributesType, ItemAttributes>
fn get_bait_attributes(&self) -> Option<&BaitAttributes>
fn get_purchasable_attributes(&self) -> Option<&PurchasableAttributes>
fn get_rod_attributes(&self) -> Option<&RodAttributes>
fn is_bait(&self) -> bool
fn is_purchasable(&self) -> bool
fn is_rod(&self) -> bool
fn get_bait_level(&self) -> Option<u64>
fn get_cost(&self) -> Option<u32>
fn get_rod_level(&self) -> Option<u64>
Sourceimpl ItemPropertiesContainerInterface for ItemData
impl ItemPropertiesContainerInterface for ItemData
fn get_properties(&self) -> &HashMap<ItemPropertiesType, ItemProperties>
fn get_properties_mut( &mut self, ) -> &mut HashMap<ItemPropertiesType, ItemProperties>
fn get_stackable_properties(&self) -> Option<&StackableComponent>
fn get_stackable_properties_mut(&mut self) -> Option<&mut StackableComponent>
fn get_usage_properties(&self) -> Option<&UsageComponent>
fn get_usage_properties_mut(&mut self) -> Option<&mut UsageComponent>
fn set_count(&mut self, count: u64)
fn is_stackable(&self) -> bool
fn has_usage(&self) -> bool
fn get_count(&self) -> Option<u64>
fn get_times_used(&self) -> Option<u64>
fn on_use(&mut self, times: u64)
fn on_add(&mut self, amount: u64)
fn on_remove(&mut self, amount: u64)
fn should_consume(&self) -> bool
impl StructuralPartialEq for ItemData