pub struct LocationData {
pub id: i32,
pub name: String,
pub timezone: Tz,
pub weather_seed: u32,
pub spring: SeasonData,
pub summer: SeasonData,
pub autumn: SeasonData,
pub winter: SeasonData,
pub required_locations_unlocked: Vec<i32>,
pub required_species_caught: Vec<i32>,
}Fields
id: i32name: Stringtimezone: Tzweather_seed: u32spring: SeasonDatasummer: SeasonDataautumn: SeasonDatawinter: SeasonDatarequired_locations_unlocked: Vec<i32>The IDs of the locations that need to be unlocked before this can
required_species_caught: Vec<i32>The IDs of the species that need to be caught before this location can be unlocked
Implementations
Sourceimpl LocationData
impl LocationData
pub fn current_season_data( &self, time: DateTime<Tz>, time_multiplier: f32, ) -> SeasonData
pub fn current_season( &self, time: DateTime<Tz>, time_multiplier: f32, ) -> (Season, f64)
pub fn full_season_information( &self, time: DateTime<Tz>, time_multiplier: f32, ) -> (SeasonData, Season, f64)
pub fn get_local_time(&self) -> DateTime<Tz>