pub struct SeasonData {
pub min_temp_c: f32,
pub max_temp_c: f32,
pub rain_intensity_raining_threshold: f32,
pub moisture_raining_threshold: f32,
pub cloudiness_raining_threshold: f32,
}Fields
min_temp_c: f32max_temp_c: f32rain_intensity_raining_threshold: f32How big the rain intensity has to be for rain to start
moisture_raining_threshold: f32How big the humidity has to be for rain to start
cloudiness_raining_threshold: f32How big the cloudiness has to be for rain to start
Implementations
Sourceimpl SeasonData
impl SeasonData
pub fn interpolate(&self, next_data: &SeasonData, progress: f32) -> Self