pub struct Settings {
pub time_speed_multiplier: f32,
pub rarity_exponent: f64,
}Fields
time_speed_multiplier: f32How much faster game speed is compared to real-time
rarity_exponent: f64How much rarer the rarest fish will be The rarest fish will be 1 in 255^(rarity_exponent) 255^(rarity_exponent) shouldn’t exceed 1.7976931348623157e+308